==> MulensModel-2.19.2-cp310-cp310-macosx_11_0_arm64.whl: MulensModel-2.19.2.dist-info/AUTHORS.md <==
MulensModel is developed as an open-source code with contributions from many individuals. These contributions are of various kinds and we would like to thank and give credit to all those people.

Main contributors:
* [Radek Poleski](https://github.com/rpoleski)
* [Yee Jennifer](https://github.com/jenniferyee)

People who have written parts of the code:
* [Lawrence Peirson](https://github.com/alpv95) - point and binary lens models with shear and convergence
* [Keto Zhang](https://github.com/ketozhang) - PyPI installation, Extensions etc.
* [Mateusz Mroz](https://github.com/mjmroz) - YAML output in example 16
* [Hariharan Srinivasulu](https://github.com/meethari) - for helping with development of FitData class

The code would not be in the state it is without modules that are imported by MulensModel. Special thanks to:
* [Valerio Bozza](https://github.com/valboz) - for VBBL
* [Jan Skowron](https://github.com/jskowron) - for Skowron & Gould root solver
* Andrew Gould - for Skowron & Gould root solver
* Martin Dominik - for AdaptiveContouring
* [Dan Foreman-Mackey](https://github.com/dfm) - for EMCEE
* AstroPy Team - for AstroPy

We also thank those who have not directly contributed to the code, but their suggestions and comments helped in code development. We thus thank (no particular order):
* [Kasia Kruszynska](https://github.com/KKruszynska)
* David Specht
* [Demitri Muna](https://github.com/demitri) - for giving excellent suggestions just before the code was born
* Zoey Samples
* [Jan Skowron](https://github.com/jskowron) - for spotting bugs and letting us know about them
* Samson Johnson - for requesting improvements in FSPL calculations
* Adrian Hernandez
* [Przemek Mroz](https://github.com/przemekmroz)
* [Geoff Bryden](https://github.com/gryden) - for early discussions about the code

==> MulensModel-2.24.0-cp310-cp310-macosx_11_0_arm64.whl: MulensModel-2.24.0.dist-info/AUTHORS.md <==
MulensModel is developed as an open-source code with contributions from many individuals. These contributions are of various kinds and we would like to thank and give credit to all those people.

Main contributors:
* [Radek Poleski](https://github.com/rpoleski)
* [Yee Jennifer](https://github.com/jenniferyee)

People who have written parts of the code:
* [Lawrence Peirson](https://github.com/alpv95) - point and binary lens models with shear and convergence
* [Keto Zhang](https://github.com/ketozhang) - PyPI installation, Extensions etc.
* [Mateusz Mroz](https://github.com/mjmroz) - YAML output in example 16
* [Raphael A. P. Oliveira](https://github.com/rapoliveira) - small updates in various places
* [Hariharan Srinivasulu](https://github.com/meethari) - for helping with development of FitData class
* [Justyna Wojtczak](https://github.com/justi) - github actions

The code would not be in the state it is without modules that are imported by MulensModel. Special thanks to:
* [Valerio Bozza](https://github.com/valboz) - for VBBL
* [Jan Skowron](https://github.com/jskowron) - for Skowron & Gould root solver
* Andrew Gould - for Skowron & Gould root solver
* Martin Dominik - for AdaptiveContouring
* [Dan Foreman-Mackey](https://github.com/dfm) - for EMCEE
* AstroPy Team - for AstroPy

We also thank those who have not directly contributed to the code, but their suggestions and comments helped in code development. We thus thank (random order):
* [Kasia Kruszynska](https://github.com/KKruszynska)
* David Specht
* [Demitri Muna](https://github.com/demitri) - for giving excellent suggestions just before the code was born
* Zoey Samples
* [Jan Skowron](https://github.com/jskowron) - for spotting bugs and letting us know about them
* [Jason Eastman](https://github.com/jdeast)
* Samson Johnson - for requesting improvements in FSPL calculations
* Adrian Hernandez
* [Przemek Mroz](https://github.com/przemekmroz)
* [Geoff Bryden](https://github.com/gryden) - for early discussions about the code
